==> peony-extensions_4.10.0.0.orig.tar.gz: peony-extensions-4.10.0.0/peony-drive-rename/translations/peony-drive-rename_kk_KZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="kk">
<context>
    <name>Peony::DriveRename</name>
    <message>
        <source>drive rename</source>
        <translation type="vanished">设备重命名</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="165"/>
        <location filename="../drive-rename.cpp" line="177"/>
        <source>Rename</source>
        <translation>Атын өзгерту</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="177"/>
        <source>Device name:</source>
        <translation>Құрылғының атауы:</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="181"/>
        <location filename="../drive-rename.cpp" line="189"/>
        <location filename="../drive-rename.cpp" line="195"/>
        <location filename="../drive-rename.cpp" line="208"/>
        <source>Warning</source>
        <translation>Ескерту</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="181"/>
        <source>Renaming cannot start with a decimal point, Please re-enter!</source>
        <translation>Атауын өзгерту ондық нүктеден басталмауы мүмкін, Қайта енгізуіңізді сұраймын!</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="189"/>
        <source>The device name exceeds the character limit, rename failed!</source>
        <translation>Құрылғының атауы таңба шегінен асып түседі, атын өзгерту сәтсіз аяқталды!</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="195"/>
        <source>Renaming will unmount the device. Do you want to continue?</source>
        <translation>Атын өзгерту құрылғыны қайта атауға мүмкіндік береді. Жалғастырғыңыз келе ме?</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="208"/>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation>Құрылғы атын өзгерту операциясын қолдамауы мүмкін, атын өзгерту жаңылысы!</translation>
    </message>
    <message>
        <source>Failed to rename!</source>
        <translation type="vanished">重命名失败！</translation>
    </message>
</context>
<context>
    <name>Peony::DriveRenamePlugin</name>
    <message>
        <location filename="../driverenameplugin.h" line="21"/>
        <source>drive rename</source>
        <translation>дискінің атын өзгерту</translation>
    </message>
</context>
<context>
    <name>Peony::DriverAction</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
<context>
    <name>Peony::SendToPlugin</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
</TS>

==> peony-extensions_4.20.0.0.orig.tar.gz: peony-extensions-4.20.0.0/peony-drive-rename/translations/peony-drive-rename_kk_KZ.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="kk">
<context>
    <name>Peony::DriveRename</name>
    <message>
        <source>drive rename</source>
        <translation type="vanished">设备重命名</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="181"/>
        <location filename="../drive-rename.cpp" line="193"/>
        <source>Rename</source>
        <translation>Атын өзгерту</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="193"/>
        <source>Device name:</source>
        <translation>Құрылғының атауы:</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="197"/>
        <location filename="../drive-rename.cpp" line="205"/>
        <location filename="../drive-rename.cpp" line="211"/>
        <source>Warning</source>
        <translation>Ескерту</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="197"/>
        <source>Renaming cannot start with a decimal point, Please re-enter!</source>
        <translation>Атауын өзгерту ондық нүктеден басталмауы мүмкін, Қайта енгізуіңізді сұраймын!</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="205"/>
        <source>The device name exceeds the character limit, rename failed!</source>
        <translation>Құрылғының атауы таңба шегінен асып түседі, атын өзгерту сәтсіз аяқталды!</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="211"/>
        <source>Renaming will unmount the device. Do you want to continue?</source>
        <translation>Атын өзгерту құрылғыны қайта атауға мүмкіндік береді. Жалғастырғыңыз келе ме?</translation>
    </message>
    <message>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation type="vanished">Құрылғы атын өзгерту операциясын қолдамауы мүмкін, атын өзгерту жаңылысы!</translation>
    </message>
    <message>
        <source>Failed to rename!</source>
        <translation type="vanished">重命名失败！</translation>
    </message>
</context>
<context>
    <name>Peony::DriveRenamePlugin</name>
    <message>
        <source>drive rename</source>
        <translation type="vanished">дискінің атын өзгерту</translation>
    </message>
    <message>
        <location filename="../driverenameplugin.h" line="41"/>
        <source>Drive rename</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Peony::DriverAction</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
<context>
    <name>Peony::SendToPlugin</name>
    <message>
        <source>Send to a removable device</source>
        <translation type="vanished">发送到移动设备</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../drive-rename.cpp" line="343"/>
        <source>Warning</source>
        <translation type="unfinished">Ескерту</translation>
    </message>
    <message>
        <location filename="../drive-rename.cpp" line="343"/>
        <source>The device may not support the rename operation, rename failed!</source>
        <translation type="unfinished">Құрылғы атын өзгерту операциясын қолдамауы мүмкін, атын өзгерту жаңылысы!</translation>
    </message>
</context>
</TS>
